@@ -445,7 +445,8 @@ def __parse_scss(payload):
 def __minify_js(in_file, out_file, verbose):
     options = ['--js %s' % in_file,
                '--js_output_file %s' % out_file,
-               '--warning_level QUIET']
+               '--warning_level QUIET',
+               '--language_in=ECMASCRIPT5_STRICT']
 
     os.system('java -jar "%s" %s' % (JS_COMPRESSOR,
                                           ' '.join(options)))
